<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2021 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2020.2/2065513
 */

use Application\Factory\InvokableServiceFactory;
use Changes\Service\Change;
use Application\Config\Services;
use Application\Model\IModelDAO;
use Changes\Model\ChangeDAO;
use Changes\Service\ChangeComparator;
use Changes\Controller\ChangeApi;
use Api\IRequest;
use Application\Controller\IndexControllerFactory;
use Changes\Controller\IndexController;

return [
    'router' => [
        'routes' => [
            'changes' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/changes?(/(?P<path>.*))?',
                    'spec'     => '/changes/%path%',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'changes',
                        'path'       => null
                    ],
                ],
            ],
            'change' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/changes?(/(?P<change>[0-9]+))/?',
                    'spec'     => '/changes/%change%',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'change',
                        'change'     => null
                    ],
                ],
            ],
            'change-fixes' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/changes?/(?P<change>[^/]+)/fixes(/(?P<mode>(add|delete)))?/?',
                    'spec'     => '/changes/%change%/fixes/%mode%',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'fixes',
                        'change'     => null,
                        'mode'       => null
                    ],
                ],
            ],
            'api' => [
                'type' => 'literal',
                'options' => [
                    'route' => '/api',
                ],
                'may_terminate' => false,
                'child_routes' => [
                    'changes' => [
                        'type' => 'Laminas\Router\Http\Segment',
                        'options' => [
                            'route' => '/:version/changes/:id',
                            'constraints' => [IRequest::VERSION => 'v10'],
                            'defaults' => [
                                'controller' => ChangeApi::class
                            ],
                        ],
                        'child_routes' => [
                            'jobs' => [
                                'type' => 'Laminas\Router\Http\Segment',
                                'options' => [
                                    'route' => '/jobs'
                                ],
                                'child_routes' => [
                                    'jobs' => [
                                        'type' => 'Laminas\Router\Http\Method',
                                        'options' => [
                                            'verb' => 'get',
                                            'defaults' => [
                                                'action' => 'jobs'
                                            ],
                                        ],
                                    ],
                                ],
                            ]
                        ]
                    ]
                ]
            ]
        ],
    ],
    'controllers' => [
        'factories' => [
            IndexController::class => IndexControllerFactory::class,
            ChangeApi::class       => IndexControllerFactory::class
        ],
    ],
    'view_manager' => [
        'template_map' => [
            'changes/index/index'  => __DIR__ . '/../view/changes/index/change.phtml',
        ],
        'template_path_stack'   => [
            __DIR__ . '/../view',
        ],
    ],
    'service_manager' => [
        'aliases' => [
            Services::CHANGE_SERVICE    => Change::class,
            Services::CHANGE_COMPARATOR => ChangeComparator::class,
            IModelDAO::CHANGE_DAO       => ChangeDAO::class
        ],
        'factories' => [
            Change::class           => InvokableServiceFactory::class,
            ChangeDAO::class        => InvokableServiceFactory::class,
            ChangeComparator::class => InvokableServiceFactory::class
        ],
    ],
    'menu_helpers' => [
        'changes' => [
            'class'    => '\Projects\Menu\Helper\ProjectAwareMenuHelper',
            'priority' => 160
        ]
    ]
];
